@@ -48,9 +48,6 @@ def local(command_string):
 class FabricException(Exception):
     pass
 
-
-
-
 TRUTH_VALUES = ['True', 'TRUE', '1', 'true', 't', 'Yes',
                 'YES', 'yes', 'y']  # arguments in fab are always strings
 
@@ -593,17 +590,20 @@ def swap_code():
 
 @task
 def rollback_code():
-    try:
+    with settings(hide('warnings'), warn_only=True):
         sudo('unlink /data/deploy/current')
         sudo('unlink /data/deploy/pending')
-    except:
-        pass
-    env.shell_escape=False
-    sudo("ln -s /data/deploy/\$(\ls -t|grep 20|head -2|\ls|grep 20|sort -r|head -2|tail -1) /data/deploy/current")   
-    sudo("ln -s /data/deploy/\$(\ls -t|grep 20|head -2|\ls|grep 20|sort -r|head -2|tail -1) /data/deploy/pending")
-    sudo("\ls -t|grep 20|head -2|\ls|grep 20|sort -r|head -1 |xargs rm -rf")  
-    env.shell_escape=True
 
+    with settings(shell_escape=False, warn_only=True):
+        t=sudo("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -2|tail -1|xargs -I \\% ln -s /data/deploy/\\% /data/deploy/current") 
+        logger.info("real: %s",t.real_command)
+        logger.info("cmd:  %s",t.command)  
+
+        sudo("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -2|tail -1|xargs -I \\% ln -s /data/deploy/\\% /data/deploy/pending")
+
+        t=sudo("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -1 |xargs -I \\% rm -rf \\%",shell_escape=False)  
+        logger.info("real: %s",t.real_command)
+        logger.info("cmd:  %s",t.command)  
 
 
 @task
